summaryrefslogtreecommitdiff
path: root/portable/dummy.c
diff options
context:
space:
mode:
Diffstat (limited to 'portable/dummy.c')
-rw-r--r--portable/dummy.c8
1 files changed, 5 insertions, 3 deletions
diff --git a/portable/dummy.c b/portable/dummy.c
index 50052ec..890bc0c 100644
--- a/portable/dummy.c
+++ b/portable/dummy.c
@@ -8,7 +8,7 @@
* The canonical version of this file is maintained in the rra-c-util package,
* which can be found at <http://www.eyrie.org/~eagle/software/rra-c-util/>.
*
- * Written by Russ Allbery <rra@stanford.edu>
+ * Written by Russ Allbery <eagle@eyrie.org>
*
* The authors hereby relinquish any claim to any copyright that they may have
* in this work, whether granted under contract or by operation of law or
@@ -19,8 +19,10 @@
* work.
*/
-/* Prototype to avoid gcc warnings. */
-int portable_dummy(void);
+#include <portable/macros.h>
+
+/* Prototype to avoid gcc warnings and set visibility. */
+int portable_dummy(void) __attribute__((__visibility__("hidden")));
int
portable_dummy(void)